scoretools.Component
====================

.. abjad-lineage:: abjad.tools.scoretools.Component.Component

.. autoclass:: abjad.tools.scoretools.Component.Component

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.scoretools.Component.Component.__copy__
      ~abjad.tools.scoretools.Component.Component.__eq__
      ~abjad.tools.scoretools.Component.Component.__format__
      ~abjad.tools.scoretools.Component.Component.__hash__
      ~abjad.tools.scoretools.Component.Component.__illustrate__
      ~abjad.tools.scoretools.Component.Component.__mul__
      ~abjad.tools.scoretools.Component.Component.__ne__
      ~abjad.tools.scoretools.Component.Component.__repr__
      ~abjad.tools.scoretools.Component.Component.__rmul__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.scoretools.Component.Component.__copy__
   :noindex:

.. automethod:: abjad.tools.scoretools.Component.Component.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.Component.Component.__format__
   :noindex:

.. automethod:: abjad.tools.scoretools.Component.Component.__hash__
   :noindex:

.. automethod:: abjad.tools.scoretools.Component.Component.__illustrate__
   :noindex:

.. automethod:: abjad.tools.scoretools.Component.Component.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.Component.Component.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.Component.Component.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.Component.Component.__rmul__
   :noindex:
